@@ -60,12 +60,12 @@ impl<'b, W: AsyncWrite + Unpin> EntryStreamWriter<'b, W> {
             file_name_length: options.filename.as_bytes().len() as u16,
             mod_time,
             mod_date,
-            version: 0,
-            flags: GeneralPurposeFlag { data_descriptor: true, encrypted: false },
+            version: crate::spec::version::as_needed_to_extract(options),
+            flags: GeneralPurposeFlag { data_descriptor: true, encrypted: false, filename_unicode: !options.filename.is_ascii() },
         };
 
         writer.writer.write_all(&crate::spec::signature::LOCAL_FILE_HEADER.to_le_bytes()).await?;
-        writer.writer.write_all(&lfh.to_slice()).await?;
+        writer.writer.write_all(&lfh.as_slice()).await?;
         writer.writer.write_all(options.filename.as_bytes()).await?;
         writer.writer.write_all(&options.extra).await?;
 
@@ -98,8 +98,8 @@ impl<'b, W: AsyncWrite + Unpin> EntryStreamWriter<'b, W> {
             compressed_size,
             uncompressed_size,
             crc,
-            v_made_by: 0,
-            v_needed: 0,
+            v_made_by: crate::spec::version::as_made_by(),
+            v_needed: self.lfh.version,
             compression: self.lfh.compression,
             extra_field_length: self.lfh.extra_field_length,
             file_name_length: self.lfh.file_name_length,
