@@ -45,13 +45,13 @@ impl<'b, 'c, W: AsyncWrite + Unpin> EntryWholeWriter<'b, 'c, W> {
             file_name_length: self.opts.filename.as_bytes().len() as u16,
             mod_time,
             mod_date,
-            version: 0,
-            flags: GeneralPurposeFlag { data_descriptor: false, encrypted: false },
+            version: crate::spec::version::as_needed_to_extract(&self.opts),
+            flags: GeneralPurposeFlag { data_descriptor: false, encrypted: false, filename_unicode: !self.opts.filename.is_ascii() },
         };
 
         let header = CentralDirectoryHeader {
-            v_made_by: 0,
-            v_needed: 0,
+            v_made_by: crate::spec::version::as_made_by(),
+            v_needed: lf_header.version,
             compressed_size: lf_header.compressed_size,
             uncompressed_size: lf_header.uncompressed_size,
             compression: lf_header.compression,
@@ -69,7 +69,7 @@ impl<'b, 'c, W: AsyncWrite + Unpin> EntryWholeWriter<'b, 'c, W> {
         };
 
         self.writer.writer.write_all(&crate::spec::signature::LOCAL_FILE_HEADER.to_le_bytes()).await?;
-        self.writer.writer.write_all(&lf_header.to_slice()).await?;
+        self.writer.writer.write_all(&lf_header.as_slice()).await?;
         self.writer.writer.write_all(self.opts.filename.as_bytes()).await?;
         self.writer.writer.write_all(&self.opts.extra).await?;
         self.writer.writer.write_all(compressed_data).await?;
